@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2016-01-22'; # DATE
-our $VERSION = '1.37'; # VERSION
+our $DATE = '2016-02-04'; # DATE
+our $VERSION = '1.38'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,7 +10,6 @@ use Devel::Confess;
 
 use Perinci::CmdLine::Gen qw(gen_pericmd_script);
 use Capture::Tiny qw(capture);
-use Data::Dumper;
 use File::Path qw(remove_tree);
 use File::Slurper qw(read_text write_text);
 use File::Temp qw(tempdir tempfile);
@@ -42,13 +41,6 @@ my %common_args = (
     },
 );
 
-sub _dump {
-    local $Data::Dumper::Deparse = 1;
-    local $Data::Dumper::Terse   = 1;
-    local $Data::Dumper::Indent  = 0;
-    Data::Dumper::Dumper($_[0]);
-}
-
 $SPEC{run_test_groups} = {
     v => 1.1,
     summary => 'Run groups of Perinci::CmdLine tests',
@@ -1067,9 +1059,9 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         inline_gen_args => {load_module=>["Perinci::Examples::Stream"]},
                         argv        => ["$tempdir/infile-int"],
                         stdout_like => qr/
-                                             ^1\n
-                                             ^9\n
-                                             ^25\n
+                                             ^"?1"?\n
+                                             ^"?9"?\n
+                                             ^"?25"?\n
                                          /mx,
                     },
                     {
@@ -1480,7 +1472,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.37 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-01-22.
+This document describes version 1.38 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-02-04.
 
 =head1 FUNCTIONS
 
